@@ -13,10 +13,13 @@ from jexp.hyd import (
 
 def clean_project(
     fname: str,
-    inc_wandb: bool = typer.Option(False, "--w", help="delete not sync wandb folder"),
-    delete_wandb: bool = typer.Option(False, "--r", help="delete wandb run"),
-    delete: bool = typer.Option(False, "--d", help="delete exps"),
+    inc_wandb: bool = typer.Option(False, "--w", help="select no-sync wandb folder"),
+    delete_wandb: bool = typer.Option(False, "--r", help="select remote wandb run"),
+    delete: bool = typer.Option(False, "--d", help="delete exps folder"),
 ):
+    """
+    delete hydra generated experiments folders
+    """
     for run in filter_hyd_stale(fname):
         if delete_wandb:
             delete_run_from_folder(run)
@@ -25,7 +28,7 @@ def clean_project(
 
     if inc_wandb:
         for run in filter_hyd_wandb(fname):
-            logger.info(f"WANDB NON SYNC: {run}")
+            logger.info(f"WANDB NO-SYNC: {run}")
             if delete:
                 shutil.rmtree(run, ignore_errors=True)
     clear_empty()
