@@ -11,8 +11,12 @@ def clean_project(
         False, "--a", help="delete runs not run in this machine"
     ),
 ):
+    """
+    `stale`: [0, 10], [7, 60], [3, 180], [1, 600] (days, run_duration/seconds)
+    `short`: three days ago and no tags
+    """
     for run in get_proj_runs(proj):
-        if if_stale(run) or if_notag(run):
+        if if_stale(run) and if_notag(run):
             delete_run(run, is_delete, is_all)
         elif name is not None and name in run.name:
             delete_run(run, is_delete, is_all)
